@@ -1,12 +1,13 @@
 package Games::Hangman;
 
-our $DATE = '2016-01-08'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2016-10-19'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 #use Color::ANSI::Util qw(ansibg ansifg);
 use Module::List qw(list_modules);
 use Module::Load;
 use Term::ReadKey;
+use Text::Unaccent;
 use Text::WideChar::Util qw(wrap);
 use Time::HiRes qw(sleep);
 
@@ -218,6 +219,16 @@ sub new_word {
         my $tries = 0;
         while (++$tries < 100) {
             $word = $self->wl->pick();
+
+            # deal with empty wordlists
+            last unless defined $word;
+
+            # for now we deal with ascii only
+            if ($word =~ /[^\x20-\x7f]/) {
+                $word = unac_string("utf8", $word);
+                next if $word =~ /[^\x20-\x7f]/;
+            }
+
             if (length($word) >= $self->min_len) {
                 last PICK;
             }
@@ -423,7 +434,7 @@ Games::Hangman - A text-based hangman
 
 =head1 VERSION
 
-This document describes version 0.04 of Games::Hangman (from Perl distribution Games-Hangman), released on 2016-01-08.
+This document describes version 0.05 of Games::Hangman (from Perl distribution Games-Hangman), released on 2016-10-19.
 
 =head1 SYNOPSIS
 
@@ -431,10 +442,6 @@ This document describes version 0.04 of Games::Hangman (from Perl distribution G
 
 =for Pod::Coverage ^(.+)$
 
-=head1 SEE ALSO
-
-L<hangman>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Games-Hangman>.
@@ -451,6 +458,10 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<hangman>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
